@@ -15,7 +15,7 @@ def create_argparser():
     parser.add_argument("--text", required = True)
     return parser
 
-def initialize_model():
+def initialize_mode():
     global e
     e=None
 
