@@ -162,10 +162,11 @@ def initialize_model(path_corpus,path_model,path_model_vocab,n):
         tfidf = compute_tfidf(tf, idfs, terms)
         top_n = get_top_terms(tfidf, n)
         top_n_terms= set()
-        for concept in top_n.index:
-            top_n_terms.add(top_n[concept])
+        for concept in concepts:
+            for term in list(top_n[concept]):
+                top_n_terms.add(term)
         top_n_terms = tuple(top_n_terms)
-        top_n_bows= [bows[term] for term in top_n_terms]
+        top_n_bows= []
         top_n_preprocessed={}
         for concept in preprocessed:
             top_n_preprocessed[concept]={}
